import { useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { User, Accounts, Cards } from '../types';
import axios from 'axios';

export default function Home () {
    const navigate = useNavigate();
    const [token, setToken] = useState<string>("");
    const [user, setUser] = useState<User>();
    const [accounts, setAccounts] = useState<Accounts>([]);
    const [cards, setCards] = useState<Cards>([]);

    useEffect(() => {
        const storedToken = localStorage.getItem("token");
        if (storedToken) {
            setToken(storedToken);
            axios
                .post("/api/@me", { token: storedToken })
                .then((response) => {
                    setUser(response.data);
                })
                .catch(() => {
                    navigate("/login");
                });

            axios
                .post("/api/@me/accounts", { token: storedToken })
                .then((response) => {
                    setAccounts(response.data);
                })
                .catch(() => {
                    console.error("Failed to fetch accounts");
                });

            axios
                .post("/api/@me/cards", { token: storedToken })
                .then((response) => {
                    setCards(response.data);
                })
                .catch(() => {
                    console.error("Failed to fetch cards");
                });
        }
    }, []);

    if (!user) {
        return (
            <div>
                <h1>Loading...</h1>
            </div>
        );
    }

    return (
        <div>
            <h1>Home</h1>
            <p>Welcome {user.name} {user.lastname}</p>
            <div>
                <h2>Your Accounts</h2>
                {accounts.length > 0 ? (
                    <ul>
                        {accounts.map((account) => (
                            <li key={account.id}>
                                Account ID: {account.id}, Balance: {account.balance}, Interest: {account.interest}
                            </li>
                        ))}
                    </ul>
                ) : (
                    <p>No accounts found.</p>
                )}
            </div>
            <div>
                <h2>Your Cards</h2>
                {cards.length > 0 ? (
                    <ul>
                        {cards.map((card) => (
                            <li key={card.id}>
                                Card ID: {card.id}, Account ID: {card.account_id}, Number: {card.number}, Expiration: {card.expiration}
                            </li>
                        ))}
                    </ul>
                ) : (
                    <p>No cards found.</p>
                )}
            </div>
        </div>
    )
}